@@ -15,7 +15,7 @@
 use strict; use warnings FATAL => 'all'; use utf8; use 5.012;
 use feature qw(state);
 package  Data::Dumper::Interp;
-$Data::Dumper::Interp::VERSION = '2.21';
+$Data::Dumper::Interp::VERSION = '2.22';
 
 package  # newline prevents Dist::Zilla::Plugin::PkgVersion from adding $VERSION
   DB;
@@ -1118,7 +1118,7 @@ Printable Unicode characters appear as themselves instead of \x{ABCD}.
 
 Note: If your data contains 'wide characters', you must encode
 the result before displaying it as explained in C<perluniintro>.
-For example with C<use open IO => ':locale';>
+For example with C<< use open IO => ':locale'; >>
 
 Undecoded binary octets (e.g. data read from a 'binmode' file)
 will be escaped as individual bytes when necessary.
